part of navigine_api;

class _HttpHelper {
  String userHash;
  String baseURL;

  initilize({
    @required String userHash,
    @required String baseURL,
  }) {
    this.userHash = userHash;
    this.baseURL = baseURL;
  }

  static final _HttpHelper _singleton = _HttpHelper._internal();

  factory _HttpHelper() {
    return _singleton;
  }

  _HttpHelper._internal();

  getRequest(
    String path, {
    Map<String, String> headers = const {},
    Map<String, String> body = const {},
  }) async {
    var url = _getUrl(path, body);

    var resp = await http.get(url, headers: headers);
    return json.decode(resp.body);
  }

  Future multipartRequest(
    String path, {
    Map<String, String> requestParams = const {},
    Map<String, String> headers = const {},
    Map<String, String> body = const {},
    Map<String, String> file = const {},
  }) async {
    Uri url = Uri.parse(_getUrl(path, requestParams));
    var request = new http.MultipartRequest("POST", url);

    body.keys.forEach((k) {
      request.fields[k] = body[k];
    });

    request.files.add(await http.MultipartFile.fromPath(
      file["field"],
      file["path"],
      contentType: new MediaType('image', 'png'),
    ));
    StreamedResponse response = await request.send();
    if (response.statusCode == 200) print("Uploaded!");
    String data = await readResponse(response);
    return json.decode(data);
  }

  Future<String> readResponse(StreamedResponse response) {
    var completer = new Completer<String>();
    var contents = new StringBuffer();
    response.stream.listen((data) {
      contents.write(String.fromCharCodes(data));
    }, onDone: () => completer.complete(contents.toString()));
    return completer.future;
  }

  postRequest(
    String path, {
    Map<String, String> requestParams = const {},
    Map<String, String> headers = const {},
    Map<String, String> body = const {},
  }) async {
    var url = _getUrl(path, requestParams);
    print(url);
    var resp = await http.post(url, body: body);
    return json.decode(resp.body);
  }

  _getUrl(String path, Map<String, String> params) {
    String url = baseURL + path + "?";
    url += "userHash=$userHash";

    params.keys.forEach((k) {
      url += "&$k=${params[k]}";
    });
    return url;
  }
}

final _HttpHelper _httpHelper = _HttpHelper();
