part of navigine_api;

class SubLocation {
  int id = 0;
  String title;
  int zoneId, mapId, sort;
  double w, h;
  String lat, lon, hor, pw, ph;
  List<Beacon> beacons = [];
  String imageFile;
  static SubLocation fromMap(var data) {
    SubLocation sl = SubLocation();
    sl.id = data["id"];
    sl.title = data["title"];
    sl.zoneId = data["zoneId"];
    sl.mapId = data["map_id"];
    sl.w = double.parse((data["w"] ?? 0).toString());
    sl.h = double.parse((data["h"] ?? 0).toString());
    sl.sort = data["sort"];
    sl.lat = data["lat"].toString();
    sl.lon = data["lon"].toString();
    sl.hor = data["hor"].toString();
    sl.pw = data["pw"].toString();
    sl.ph = data["ph"].toString();

    return sl;
  }

  Future getImageURL() async {
    var resp = await _httpHelper.getRequest("sublocation/get", body: {
      "sublocationId": id.toString(),
    });
    imageFile = resp["files"][0]["fullPath"];
    return imageFile;
  }

  Future<List<Beacon>> getAllBeacons() async {
    var resp = await _httpHelper.getRequest("beacon/getAll", body: {
      "sublocationId": id.toString(),
    });
    beacons =
        await resp["beacons"].map<Beacon>((b) => Beacon.fromMap(b)).toList();
    return beacons;
  }

  Future<bool> addBeacon({
    @required String description,
    @required String uuid,
    @required int major,
    @required int minor,
    @required int pw,
    @required double kx,
    @required double ky,
    int isUsed = 0,
  }) async {
    var data = await _httpHelper.postRequest(
      "beacon/add",
      requestParams: {
        "sublocationId": id.toString(),
      },
      body: {
        "description": description,
        "major": major.toString(),
        "minor": minor.toString(),
        "uuid": uuid,
        "pw": pw.toString(),
        "kx": kx.toString(),
        "ky": ky.toString(),
        "isUsed": isUsed.toString(),
      },
    );

    return data["response"] == "ok";
  }
}
