library navigine_api;

import 'dart:io';
import 'dart:async';
import "dart:convert";
import 'package:meta/meta.dart';
import 'package:http/http.dart';
import "package:http/http.dart" as http;
import 'package:http_parser/http_parser.dart';

part 'models/location.dart';
part 'models/sub_location.dart';
part 'models/beacon.dart';
part 'helpers/http_helper.dart';

class NavigineAPI {
  String userHash, serverURL;

  NavigineAPI.initilize({
    @required this.userHash,
    this.serverURL = "https://api.navigine.com/",
  }) {
    _httpHelper.initilize(userHash: userHash, baseURL: serverURL);
  }

  Future<List<Location>> getAllLocations() async {
    var resp = await _httpHelper.getRequest("locations/getAll");
    if (resp["error"] != null) {
      return resp["locations"]
          .map<Location>((l) => Location.fromMap(l))
          .toList();
    } else {
      throw Exception("Unable to get all locations detail.");
    }
  }

  Future<Location> getLocation(int locationId) async {
    var resp = await _httpHelper.getRequest("locations/get", body: {
      "id": locationId.toString(),
    });
    if (resp["error"] == null) {
      return Location.fromMap(resp["location"]);
    } else {
      throw Exception("Unable to fetch location detail for indoor.");
    }
  }

  Future<Location> createNewLocation(String name) async {
    var resp = await _httpHelper.postRequest("locations/add", body: {
      "title": name,
      "description": "",
      "publicLocation": "0",
    });

    print(resp);
    return Location.fromMap(resp);
  }
}
